#
# spec file for package python-pyinotify
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif

%{?sle15_python_module_pythons}
Name:           python-pyinotify
Version:        0.9.6
Release:        7.1
Summary:        Python module for watching filesystems changes
License:        MIT
Group:          Development/Libraries/Python
URL:            https://github.com/seb-m/pyinotify
Source:         https://files.pythonhosted.org/packages/source/p/pyinotify/pyinotify-%{version}.tar.gz
Source1:        pyinotify
# PATCH-FIX_UPSTREAM https://github.com/seb-m/pyinotify/pull/205
Patch0:         make_asyncore_support_optional.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
%if %{with libalternatives}
Requires:       alts
BuildRequires:  alts
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif
BuildArch:      noarch
%python_subpackages

%description
pyinotify is a Python module for watching filesystems changes. By its design
pyinotify can be used for any kind of fs monitoring.

pyinotify relies on a recent Linux Kernel feature (merged in kernel 2.6.13)
called inotify. inotify is an event-driven notifier, its notifications are
exported from kernel space to user space. The raw interface of inotify is
compounded of three system calls. pyinotify binds these system calls and
provides an implementation on top of them offering a generic and abstract way
to use inotify with Python. Pyinotify doesn't requires much detailed knowledge
of inotify. Moreover, it only needs few statements for initializing, watching,
handling (eventually trough a new separate thread), and processing events
notifications through subclassing. The only things to know is the path of items
to watch, the kind of events to monitor and the actions to execute on these
notifications.

%prep
%autosetup -p1 -n pyinotify-%{version}
# remove unwanted shebang
sed -i '/^#!/ d' python2/pyinotify.py
sed -i "s|#!%{_bindir}/env python|#!%__python2|" python2/examples/*py
sed -i "s|#!%{_bindir}/env python|#!%__python3|" python3/examples/*py

%build
%python_build

%install
%python_install
install -D -m 0755 %{SOURCE1} %{buildroot}%{_bindir}/pyinotify
%python_clone -a %{buildroot}%{_bindir}/pyinotify

%pre
# If libalternatives is used: Removing old update-alternatives entries.
%python_libalternatives_reset_alternative pyinotify

%post
%python_install_alternative pyinotify

%postun
%python_uninstall_alternative pyinotify

%files %{python_files}
%license COPYING
%doc ACKS README.md
%doc old/ChangeLog old/NEWS
%doc python3/examples
%python_alternative %{_bindir}/pyinotify
%{python_sitelib}/pyinotify.py
%{python_sitelib}/pyinotify-%{version}*.egg-info
%pycache_only %{python_sitelib}/__pycache__

%changelog
* Wed Mar 26 2025 Nico Krapp <nico.krapp@suse.com>
- Use libalternatives instead of update-alternatives, bsc#1240097
- No more greedy globs in %%files.
- Use python3 in pyinotify script
* Fri Mar 21 2025 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Make asyncore support optional to fix issue in Python 3.12 and 3.13
- Added:
  * make_asyncore_support_optional.patch
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon Jan  4 2016 dmueller@suse.com
- update to 0.9.6:
  * fixes for sysctl compatibility issues
* Mon May 11 2015 benoit.monin@gmx.fr
- update to version 0.9.5:
  * no changelog available
- point the source URL to pypi
- remove unwanted shebang in pyinotify.py
* Fri Jan 18 2013 saschpe@suse.de
- Avoid using github source link to please factory-auto
* Sun Jan 13 2013 p.drouand@gmail.com
- Initial python3 support
* Sun Jan 13 2013 p.drouand@gmail.com
- Update to 0.9.4 version
- Cleanup spec file
* Tue Feb 21 2012 poeml@cmdline.net
- spec file boiler plate update (by the system, or someone)
* Tue Nov  2 2010 prusnak@opensuse.org
- add pyinotify wrapper
- fix license in spec file
* Thu Oct 28 2010 prusnak@opensuse.org
- updated to 0.9.1
- cleanup spec file
* Mon Oct 11 2010 pascal.bleser@opensuse.org
- update to 0.9.0
* Tue Jun 17 2008 poeml@suse.de
- update to 0.7.1
* Fri Sep 15 2006 poeml@suse.de
- create package (version 0.6.2)
